summaryrefslogtreecommitdiffstats
path: root/src/kiro-server.h
diff options
context:
space:
mode:
authorTimo Dritschler <timo.dritschler@kit.edu>2014-07-25 11:32:55 +0200
committerTimo Dritschler <timo.dritschler@kit.edu>2014-07-25 11:40:36 +0200
commitdead85f8d5aa2445b1de723979b78d973a522310 (patch)
treef8bb612af06b36b79e2409e963cac5b218d1bd9c /src/kiro-server.h
parent0bc62ec853049abc4abc724bbde142e8e56b2931 (diff)
downloadkiro-dead85f8d5aa2445b1de723979b78d973a522310.tar.gz
kiro-dead85f8d5aa2445b1de723979b78d973a522310.tar.bz2
kiro-dead85f8d5aa2445b1de723979b78d973a522310.tar.xz
kiro-dead85f8d5aa2445b1de723979b78d973a522310.zip
Added 'kiro_server_stop' method to KIRO Server
Added missing cleanup to kiro_server_finalize Added missing cleanup to test-server
Diffstat (limited to 'src/kiro-server.h')
-rw-r--r--src/kiro-server.h14
1 files changed, 12 insertions, 2 deletions
diff --git a/src/kiro-server.h b/src/kiro-server.h
index cb9b57c..ea853c3 100644
--- a/src/kiro-server.h
+++ b/src/kiro-server.h
@@ -78,13 +78,13 @@ GObject kiro_server_new (void);
/**
* kiro_server_start - Starts the server, providing the given memory
* @server: KIRO SERVER to perform the operation on
* @bind_addr: Local address to bind the server to
* @bind_port: Local port to listen for connections
* @mem: Pointer to the memory that is to be provided
* @mem_size: Size in bytes of the given memory
* Description:
* Starts the server to provide the given memory to any connecting
* client.
* Notes:
* If the bind_addr is NULL, the server will bind to the first device
@@ -101,6 +101,16 @@ GObject kiro_server_new (void);
*/
int kiro_server_start (KiroServer* server, char* bind_addr, char* bind_port, void* mem, size_t mem_size);
+/**
+ * kiro_server_stop - Stops the server
+ * @server: #KiroServer to perform the operation on
+ * Description:
+ * Stops the given #KiroServer
+ * See also:
+ * kiro_server_start
+ */
+void kiro_server_stop (KiroServer* server);
+
G_END_DECLS
#endif //__KIRO_SERVER_H \ No newline at end of file
@@ -78,13 +78,13 @@ GObject kiro_server_new (void);
/**
* kiro_server_start - Starts the server, providing the given memory
- * @server: KIRO SERVER to perform the operation on
+ * @server: #KiroServer to perform the operation on
* @bind_addr: Local address to bind the server to
* @bind_port: Local port to listen for connections
@@ -78,13 +78,13 @@ GObject kiro_server_new (void);
* @mem_size: Size in bytes of the given memory
* Description:
- * Starts the server to provide the given memory to any connecting
+ * Starts the #KiroServer to provide the given memory to any connecting
* client.
* Notes: